autoAdvanceOnValidation property
Whether to automatically advance to the next step when the current step is validated
Implementation
final bool autoAdvanceOnValidation;
Whether to automatically advance to the next step when the current step is validated
final bool autoAdvanceOnValidation;