StepIndicator<TStepData> class
abstract
Abstract class for step indicators with generic type support
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- StepIndicator
- Implementers
Constructors
-
StepIndicator({Key? key, FlowBloc<
TStepData> ? bloc, void onStepTapped(int)?, StepIndicatorThemeData? theme}) -
const
Properties
-
bloc
→ FlowBloc<
TStepData> ? -
Optional FlowBloc instance
If not provided, it will be obtained from the nearest BlocProvider
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onStepTapped → void Function(int)?
-
Callback when a step is tapped
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- theme → StepIndicatorThemeData?
-
Theme data for the indicator
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
buildIndicator(
BuildContext context, FlowState< TStepData> state) → Widget - Abstract method to build the indicator UI
-
canSelectStep(
FlowState< TStepData> state, int index) → bool - Whether a step at the given index can be selected
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
getCurrentStepIndex(
FlowState< TStepData> state) → int - Current step index
-
getStepColor(
BuildContext context, FlowState< TStepData> state, int index) → Color - Get the color for a step at the given index
-
getStepCount(
FlowState< TStepData> state) → int - Total number of steps
-
getStepLabel(
FlowState< TStepData> state, int index) → String? - Get the label for a step at the given index
-
handleStepTap(
BuildContext context, FlowState< TStepData> state, int index) → void - Handle step tap
-
isComplete(
FlowState< TStepData> state) → bool - Whether the flow is complete
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited